uploads.UploadType (Upload type) — amici1

# `uploads.UploadType` (Upload type)

UploadType(id, name, upload_area, max_number, wanted, shortcut, name_de, name_fr)

Master tables : uploads.UploadTypes (Upload types)

Slave tables : uploads.UploadsByType (Upload files)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Upload area (upload_area) : See `<lino.core.choicelists.ChoiceListField: upload_area>`.

- Max. number (max_number) : No need to upload more uploads than N of this type. -1 means no limit.

- Wanted (wanted) : Add a (+) button when there is no upload of this type.

- Upload shortcut (shortcut) : Optional pointer to a virtual upload shortcut field. If this is not empty, then the given shortcut field will manage uploads of this type. See also Shortcuts.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino.modlib.uploads.models.UploadType.name_column`.

- (None) (navigation_panel) : See `lino.modlib.uploads.models.UploadType.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.uploads.models.UploadType.overview`.

Referenced from uploads.Upload.type

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
name | Designation |
upload_area | Upload area |
max_number | Max. number | No need to upload more uploads than N of this type. -1 means no limit.
wanted | Wanted | Add a (+) button when there is no upload of this type.
shortcut | Upload shortcut | Optional pointer to a virtual upload shortcut field. If this is not empty, then the given shortcut field will manage uploads of this type. See also Shortcuts.
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |